@@ -292,10 +292,11 @@ randomForestSRC.var.select = makeFilter( # nolint
     # method "vh.imp" is not supported as it does return values to rank features on
     assert_choice(method, c("md", "vh"))
     im = randomForestSRC::var.select(getTaskFormula(task), getTaskData(task),
-      method = method, verbose = FALSE, always.use = getTaskFeatureNames(task),
+      method = method, verbose = FALSE,
       ...)
+
     im$varselect[setdiff(rownames(im$varselect), im$topvars), "depth"] = NA
-    im$topvars
+    setNames(im$varselect[, "depth"], rownames(im$varselect))
   })
 .FilterRegister[["randomForestSRC.var.select"]] = randomForestSRC.var.select
 .FilterRegister[["randomForestSRC.var.select"]]$desc = "(DEPRECATED)"
@@ -950,7 +951,7 @@ makeFilter(
   name = "praznik_JMI",
   desc = "Joint mutual information filter",
   pkg = "praznik",
-  supported.tasks = "classif",
+  supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors", "integer", "character", "logical"),
   fun = praznik_filter("JMI")
 )
@@ -961,7 +962,7 @@ makeFilter(
   name = "praznik_DISR",
   desc = "Double input symmetrical relevance filter",
   pkg = "praznik",
-  supported.tasks = "classif",
+  supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors", "integer", "character", "logical"),
   fun = praznik_filter("DISR")
 )
@@ -972,7 +973,7 @@ makeFilter(
   name = "praznik_JMIM",
   desc = "Minimal joint mutual information maximisation filter",
   pkg = "praznik",
-  supported.tasks = "classif",
+  supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors", "integer", "character", "logical"),
   fun = praznik_filter("JMIM")
 )
@@ -983,7 +984,7 @@ makeFilter(
   name = "praznik_MIM",
   desc = "conditional mutual information based feature selection filters",
   pkg = "praznik",
-  supported.tasks = "classif",
+  supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors", "integer", "character", "logical"),
   fun = praznik_filter("MIM")
 )
@@ -994,7 +995,7 @@ makeFilter(
   name = "praznik_NJMIM",
   desc = "Minimal normalised joint mutual information maximisation filter",
   pkg = "praznik",
-  supported.tasks = "classif",
+  supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors", "integer", "character", "logical"),
   fun = praznik_filter("NJMIM")
 )
@@ -1005,7 +1006,7 @@ makeFilter(
   name = "praznik_MRMR",
   desc = "Minimum redundancy maximal relevancy filter",
   pkg = "praznik",
-  supported.tasks = c("classif", "regr", "surv"),
+  supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors", "integer", "character", "logical"),
   fun = praznik_filter("MRMR")
 )
